@@ -6,7 +6,9 @@ setClass("RococoTestResults",
                                        p.value="numeric",
                                        r.values="numeric",
                                        numtests="integer",
+                                       exact="logical",
                                        similarity="character",
                                        sample.gamma="numeric",
                                        H0gamma.sd="numeric",
+                                       perm.gamma="numeric",
                                        alternative="character"))
